# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kwil/tx/v1/service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from kwil.tx.v1 import broadcast_pb2 as kwil_dot_tx_dot_v1_dot_broadcast__pb2
from kwil.tx.v1 import price_pb2 as kwil_dot_tx_dot_v1_dot_price__pb2
from kwil.tx.v1 import query_pb2 as kwil_dot_tx_dot_v1_dot_query__pb2
from kwil.tx.v1 import ping_pb2 as kwil_dot_tx_dot_v1_dot_ping__pb2
from kwil.tx.v1 import account_pb2 as kwil_dot_tx_dot_v1_dot_account__pb2
from kwil.tx.v1 import config_pb2 as kwil_dot_tx_dot_v1_dot_config__pb2
from kwil.tx.v1 import list_pb2 as kwil_dot_tx_dot_v1_dot_list__pb2
from kwil.tx.v1 import dataset_pb2 as kwil_dot_tx_dot_v1_dot_dataset__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18kwil/tx/v1/service.proto\x12\x02tx\x1a\x1akwil/tx/v1/broadcast.proto\x1a\x16kwil/tx/v1/price.proto\x1a\x16kwil/tx/v1/query.proto\x1a\x15kwil/tx/v1/ping.proto\x1a\x18kwil/tx/v1/account.proto\x1a\x17kwil/tx/v1/config.proto\x1a\x15kwil/tx/v1/list.proto\x1a\x18kwil/tx/v1/dataset.proto\x1a\x1cgoogle/api/annotations.proto2\xcc\x05\n\tTxService\x12V\n\tBroadcast\x12\x14.tx.BroadcastRequest\x1a\x15.tx.BroadcastResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\"\x11/api/v1/broadcast:\x01*\x12g\n\rEstimatePrice\x12\x18.tx.EstimatePriceRequest\x1a\x19.tx.EstimatePriceResponse\"!\x82\xd3\xe4\x93\x02\x1b\"\x16/api/v1/estimate_price:\x01*\x12\x46\n\x05Query\x12\x10.tx.QueryRequest\x1a\x11.tx.QueryResponse\"\x18\x82\xd3\xe4\x93\x02\x12\"\r/api/v1/query:\x01*\x12_\n\nGetAccount\x12\x15.tx.GetAccountRequest\x1a\x16.tx.GetAccountResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/api/v1/accounts/{address}\x12?\n\x04Ping\x12\x0f.tx.PingRequest\x1a\x10.tx.PingResponse\"\x14\x82\xd3\xe4\x93\x02\x0e\x12\x0c/api/v1/ping\x12P\n\tGetConfig\x12\x14.tx.GetConfigRequest\x1a\x15.tx.GetConfigResponse\"\x16\x82\xd3\xe4\x93\x02\x10\x12\x0e/api/v1/config\x12_\n\rListDatabases\x12\x18.tx.ListDatabasesRequest\x1a\x19.tx.ListDatabasesResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/api/v1/databases\x12\x61\n\tGetSchema\x12\x14.tx.GetSchemaRequest\x1a\x15.tx.GetSchemaResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/api/v1/databases/{dbid}/schemaB\x1eZ\x1ckwil/api/protobuf/tx/v1;txpbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kwil.tx.v1.service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\034kwil/api/protobuf/tx/v1;txpb'
  _TXSERVICE.methods_by_name['Broadcast']._options = None
  _TXSERVICE.methods_by_name['Broadcast']._serialized_options = b'\202\323\344\223\002\026\"\021/api/v1/broadcast:\001*'
  _TXSERVICE.methods_by_name['EstimatePrice']._options = None
  _TXSERVICE.methods_by_name['EstimatePrice']._serialized_options = b'\202\323\344\223\002\033\"\026/api/v1/estimate_price:\001*'
  _TXSERVICE.methods_by_name['Query']._options = None
  _TXSERVICE.methods_by_name['Query']._serialized_options = b'\202\323\344\223\002\022\"\r/api/v1/query:\001*'
  _TXSERVICE.methods_by_name['GetAccount']._options = None
  _TXSERVICE.methods_by_name['GetAccount']._serialized_options = b'\202\323\344\223\002\034\022\032/api/v1/accounts/{address}'
  _TXSERVICE.methods_by_name['Ping']._options = None
  _TXSERVICE.methods_by_name['Ping']._serialized_options = b'\202\323\344\223\002\016\022\014/api/v1/ping'
  _TXSERVICE.methods_by_name['GetConfig']._options = None
  _TXSERVICE.methods_by_name['GetConfig']._serialized_options = b'\202\323\344\223\002\020\022\016/api/v1/config'
  _TXSERVICE.methods_by_name['ListDatabases']._options = None
  _TXSERVICE.methods_by_name['ListDatabases']._serialized_options = b'\202\323\344\223\002\023\022\021/api/v1/databases'
  _TXSERVICE.methods_by_name['GetSchema']._options = None
  _TXSERVICE.methods_by_name['GetSchema']._serialized_options = b'\202\323\344\223\002!\022\037/api/v1/databases/{dbid}/schema'
  _TXSERVICE._serialized_start=262
  _TXSERVICE._serialized_end=978
# @@protoc_insertion_point(module_scope)
