# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kwil/tx/v1/broadcast.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from kwil.tx.v1 import tx_pb2 as kwil_dot_tx_dot_v1_dot_tx__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1akwil/tx/v1/broadcast.proto\x12\x02tx\x1a\x13kwil/tx/v1/tx.proto\"&\n\x10\x42roadcastRequest\x12\x12\n\x02tx\x18\x01 \x01(\x0b\x32\x06.tx.Tx\"3\n\x11\x42roadcastResponse\x12\x1e\n\x07receipt\x18\x01 \x01(\x0b\x32\r.tx.TxReceiptB\x1eZ\x1ckwil/api/protobuf/tx/v1;txpbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kwil.tx.v1.broadcast_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\034kwil/api/protobuf/tx/v1;txpb'
  _BROADCASTREQUEST._serialized_start=55
  _BROADCASTREQUEST._serialized_end=93
  _BROADCASTRESPONSE._serialized_start=95
  _BROADCASTRESPONSE._serialized_end=146
# @@protoc_insertion_point(module_scope)
