# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kwil/tx/v1/dataset.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18kwil/tx/v1/dataset.proto\x12\x02tx\" \n\x10GetSchemaRequest\x12\x0c\n\x04\x64\x62id\x18\x01 \x01(\t\"1\n\x11GetSchemaResponse\x12\x1c\n\x07\x64\x61taset\x18\x01 \x01(\x0b\x32\x0b.tx.Dataset\"^\n\x07\x44\x61taset\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x19\n\x06tables\x18\x03 \x03(\x0b\x32\t.tx.Table\x12\x1b\n\x07\x61\x63tions\x18\x04 \x03(\x0b\x32\n.tx.Action\"N\n\x05Table\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1b\n\x07\x63olumns\x18\x02 \x03(\x0b\x32\n.tx.Column\x12\x1a\n\x07indexes\x18\x03 \x03(\x0b\x32\t.tx.Index\"U\n\x06\x43olumn\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1a\n\x04type\x18\x02 \x01(\x0e\x32\x0c.tx.DataType\x12!\n\nattributes\x18\x03 \x03(\x0b\x32\r.tx.Attribute\";\n\tAttribute\x12\x1f\n\x04type\x18\x01 \x01(\x0e\x32\x11.tx.AttributeType\x12\r\n\x05value\x18\x02 \x01(\x0c\"C\n\x05Index\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07\x63olumns\x18\x02 \x03(\t\x12\x1b\n\x04type\x18\x03 \x01(\x0e\x32\r.tx.IndexType\"J\n\x06\x41\x63tion\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06public\x18\x02 \x01(\x08\x12\x0e\n\x06inputs\x18\x03 \x03(\t\x12\x12\n\nstatements\x18\x04 \x03(\t*^\n\x08\x44\x61taType\x12\x15\n\x11INVALID_DATA_TYPE\x10\x00\x12\x12\n\x0eNULL_DATA_TYPE\x10\x01\x12\x14\n\x10STRING_DATA_TYPE\x10\x02\x12\x11\n\rINT_DATA_TYPE\x10\x03*\x90\x01\n\rAttributeType\x12\x15\n\x11INVALID_ATTRIBUTE\x10\x00\x12\x0f\n\x0bPRIMARY_KEY\x10\x01\x12\n\n\x06UNIQUE\x10\x02\x12\x0c\n\x08NOT_NULL\x10\x03\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x04\x12\x07\n\x03MIN\x10\x05\x12\x07\n\x03MAX\x10\x06\x12\x0e\n\nMIN_LENGTH\x10\x07\x12\x0e\n\nMAX_LENGTH\x10\x08*V\n\tIndexType\x12\x16\n\x12INVALID_INDEX_TYPE\x10\x00\x12\x14\n\x10\x42TREE_INDEX_TYPE\x10\x01\x12\x1b\n\x17UNIQUE_BTREE_INDEX_TYPE\x10\x02\x42\x1eZ\x1ckwil/api/protobuf/tx/v1;txpbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kwil.tx.v1.dataset_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\034kwil/api/protobuf/tx/v1;txpb'
  _DATATYPE._serialized_start=586
  _DATATYPE._serialized_end=680
  _ATTRIBUTETYPE._serialized_start=683
  _ATTRIBUTETYPE._serialized_end=827
  _INDEXTYPE._serialized_start=829
  _INDEXTYPE._serialized_end=915
  _GETSCHEMAREQUEST._serialized_start=32
  _GETSCHEMAREQUEST._serialized_end=64
  _GETSCHEMARESPONSE._serialized_start=66
  _GETSCHEMARESPONSE._serialized_end=115
  _DATASET._serialized_start=117
  _DATASET._serialized_end=211
  _TABLE._serialized_start=213
  _TABLE._serialized_end=291
  _COLUMN._serialized_start=293
  _COLUMN._serialized_end=378
  _ATTRIBUTE._serialized_start=380
  _ATTRIBUTE._serialized_end=439
  _INDEX._serialized_start=441
  _INDEX._serialized_end=508
  _ACTION._serialized_start=510
  _ACTION._serialized_end=584
# @@protoc_insertion_point(module_scope)
