# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kwil/tx/v1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13kwil/tx/v1/tx.proto\x12\x02tx\"\x95\x01\n\x02Tx\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\x12\"\n\x0cpayload_type\x18\x02 \x01(\x05R\x0cpayload_type\x12\x0f\n\x07payload\x18\x03 \x01(\x0c\x12\r\n\x05nonce\x18\x04 \x01(\x03\x12 \n\tsignature\x18\x05 \x01(\x0b\x32\r.tx.Signature\x12\x0b\n\x03\x66\x65\x65\x18\x06 \x01(\t\x12\x0e\n\x06sender\x18\x07 \x01(\t\"p\n\tSignature\x12(\n\x0fsignature_bytes\x18\x01 \x01(\x0cR\x0fsignature_bytes\x12\x39\n\x0esignature_type\x18\x02 \x01(\x0e\x32\x11.tx.SignatureTypeR\x0esignature_type\"7\n\tTxReceipt\x12\x0f\n\x07tx_hash\x18\x01 \x01(\x0c\x12\x0b\n\x03\x66\x65\x65\x18\x02 \x01(\t\x12\x0c\n\x04\x62ody\x18\x03 \x01(\x0c*\x85\x01\n\rSignatureType\x12\x19\n\x15INVALID_SINATURE_TYPE\x10\x00\x12\x1d\n\x19PK_SECP256K1_UNCOMPRESSED\x10\x01\x12\"\n\x1e\x41\x43\x43OUNT_SECP256K1_UNCOMPRESSED\x10\x02\x12\x16\n\x12\x45ND_SIGNATURE_TYPE\x10\x03\x42\x1eZ\x1ckwil/api/protobuf/tx/v1;txpbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kwil.tx.v1.tx_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\034kwil/api/protobuf/tx/v1;txpb'
  _SIGNATURETYPE._serialized_start=351
  _SIGNATURETYPE._serialized_end=484
  _TX._serialized_start=28
  _TX._serialized_end=177
  _SIGNATURE._serialized_start=179
  _SIGNATURE._serialized_end=291
  _TXRECEIPT._serialized_start=293
  _TXRECEIPT._serialized_end=348
# @@protoc_insertion_point(module_scope)
